<!DOCTYPE html>
<html>
<head>
<title>Le Hachoir - {% block title %}{% if title %}{{ title }}{% else %}No Title{% endif %}{% endblock %}</title>
{% block head %}
{% endblock %}
<style type="text/css">
body {background-color:#1C1C1C; color:#e0e0e0; margin:0; padding:0;}
h1,
h2,
h3,
.response_messages li,
.links li,
p
    {padding:8px 16px;}
.response_messages,
.links
    {list-style-type:none; margin:0; padding:0;}
li {margin:0;}
.response_messages li.info {background-color:#C4D1FF; color:#111640;}
.response_messages li:first-child {border-top:1px dotted;}
.response_messages li {border-bottom:1px dotted;}
.response_messages li.warning {background-color:#FFF6B7; color:#14140F;}
.response_messages li.error {background-color:#FFB4A9; color:#BF2F16;}
a {color:inherit; text-decoration:none;}
a:hover, a:active {text-decoration:underline;}

/* batch status formatting */
table.batch_items {text-align:left; border-collapse:collapse;}
table.batch_items td,
table.batch_items th
    {padding:8px 16px;}
a:link,
a:visited,
a:hover,
a:active
    {text-decoration:none;}
a:link,
a:visited
    {border-bottom:1px dotted #505050;}
a:hover,
a:active
    {border-bottom:1px solid #fff; color:#fff}
</style>
</head>
<body>
{% block body %}
{% if title %}<h1>{{ title }}</h1>{% endif %} 
{% if response_messages %}
<h2>Response Messages</h2>
<ol class="response_messages">
{% for m in response_messages %}
    <li class="{{ m.type }}">{{ m.content }}</li>
{% endfor %}
</ol>
{% elif links %}
<ul class="links">
{% for l in links %}
    <li><a href="{{ l.href }}">{{ l.display }}</a></li>
{% endfor %}
</ul>
{% else %}<p>No content.</p>{% endif %}
{% endblock %}
</body>
</html>