{% extends "djhcup_base.html" %}


{% block title %}{{ title }}{% endblock %}


{% block body %}
    <h1>{{ title }}</h1>

    <h2>Module availability</h2>
    
    {% if djhcup_components %}
        <ul>
        {% for mod, avail in djhcup_components.items %}
            <li>{{ mod }}: {{ avail }} {% if avail %}<a href="{% url mod|add:'.views.index' %}">Go&rarr;</a>{% endif %}</li>
        {% endfor %}
        </ul>
    {% else %}
        <p>Unable to determine module availability.</p>
    {% endif %}

{% endblock %}
